<?php

/**
 * Gestion de l'action pour peupler spip_gis
 *
 * L'action a pour objet de permettre de disposer en une seule fois de tous les contours
 * nécessaires à la visualisation des subdivisions composant un pays.
 *
 * @plugin Subdivisions
 **/

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Action pour obtenir les contours nécessaires à la visualisation des subdivisions d'un pays
 *
 * L'argument attendu : Le pays, la strate de subdivisions, le type d'objet
 *
 * @param string 
 *		pays
 *		niveau
 *		type_forme
 * @return void
 */
 
function action_subdivisions_peupler_pays_dist ($arg = null) {
	if (is_null($arg)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arg = $securiser_action();
	}

	$arg = explode("-", $arg);
	list($iso_pays, $niveau, $type_forme) = $arg;

	// vérification des arguments transmis
	$iso_pays = strtoupper ($iso_pays); // au cas ou l'appel n'aurait pas été fait avec des majuscules
	if ((!preg_match('/^[A-Z]{2}$/', $iso_pays))
		OR
		(!in_array($niveau, array('1','2','*')))
		OR
		(!in_array($type_forme, array('definition')))
		) {
		spip_log("action_subdivisions_peupler_pays_dist. arg non compris. arg = " 
				. implode('-',$arg), 'subdivisions.' . _LOG_INFO_IMPORTANTE);
		return;
	}

	// obtenir les données nécessaires à la gestion localisée
	switch ($iso_pays) {
   		case 'FR':
       		// liste du premier niveau de subdivisions du pays (Régions pour la France)
			$liste_iso_1 = array('FR-GUA', 'FR-MTQ', 'FR-GUF', 'FR-LRE', 'FR-MAY', 'FR-IDF', 'FR-CVL', 'FR-BFC', 'FR-NOR', 
				'FR-HDF', 'FR-GES', 'FR-PDL', 'FR-BRE', 'FR-NAQ', 'FR-OCC', 'FR-ARA', 'FR-PAC', 'FR-COR');
			// liste du second niveau de subdivisions du pays (Départements pour la France)
			$liste_iso_2 = array('FR-GP', 'FR-MQ', 'FR-GF', 'FR-RE', 'FR-YT', 'FR-01', 'FR-02', 'FR-03', 'FR-04', 'FR-05',
						'FR-06', 'FR-07', 'FR-08', 'FR-09', 'FR-10', 'FR-11', 'FR-12', 'FR-13', 'FR-14', 'FR-15', 'FR-16',
						'FR-17', 'FR-18', 'FR-19', 'FR-2A', 'FR-2B', 'FR-21', 'FR-22', 'FR-23', 'FR-24', 'FR-25', 'FR-26',
						'FR-27', 'FR-28', 'FR-29', 'FR-30', 'FR-31', 'FR-32', 'FR-33', 'FR-34', 'FR-35', 'FR-36', 'FR-37',
						'FR-38', 'FR-39', 'FR-40', 'FR-41', 'FR-42', 'FR-43', 'FR-44', 'FR-45', 'FR-46', 'FR-47', 'FR-48',
						'FR-49', 'FR-50', 'FR-51', 'FR-52', 'FR-53', 'FR-54', 'FR-55', 'FR-56', 'FR-57', 'FR-58', 'FR-59',
						'FR-60', 'FR-61', 'FR-62', 'FR-63', 'FR-64', 'FR-65', 'FR-66', 'FR-67', 'FR-68', 'FR-69', 'FR-70',
						'FR-71', 'FR-72', 'FR-73', 'FR-74', 'FR-75', 'FR-76', 'FR-77', 'FR-78', 'FR-79', 'FR-80', 'FR-81',
						'FR-82', 'FR-83', 'FR-84', 'FR-85', 'FR-86', 'FR-87', 'FR-88', 'FR-89', 'FR-90', 'FR-91', 'FR-92',
						'FR-93', 'FR-94', 'FR-95');
			// le cas des contours en commun (les régions d'outre-mer correspondent aux départements)
			$d = array(
				'FR-GUA' => 'FR-GP',
				'FR-MTQ' => 'FR-MQ',
				'FR-GUF' => 'FR-GF',
				'FR-LRE' => 'FR-RE',
				'FR-MAY' => 'FR-YT'
			);
			break;
     	default:
			spip_log("action_subdivisions_peupler_pays_dist. Pays non géré. pays = $iso_pays",
				'subdivisions.' . _LOG_INFO_IMPORTANTE);
			return;
	}

	// déterminer la liste à utiliser
	$liste = array();
	if ($niveau == '2') {
		$liste = $liste_iso_2;
	} elseif ($niveau == '1'){
		$liste = $liste_iso_1;
	} else {
		$liste = array_merge($liste_iso_1, $liste_iso_2);
	}

       
	// Traiter les arguments et les données localisées avec la liste retenue
	include_spip('inc/apigeo');
	include_spip('inc/distant');
	include_spip('inc/invalideur');
	foreach ($liste as $iso_moi) {
		// quels sont l'id_subdivision et l'id_subdivision_api correspondants au code iso
		$identifiants = apigeo_correspondances_iso($iso_moi);
		$id_subdivision_api = $identifiants['id_subdivision_api']; $id_subdivision = $identifiants['id_subdivision'];
		if (!$id_subdivision_api OR !$id_subdivision) {
			spip_log("action_subdivisions_peupler_pays_dist." .
				" Impossible de donner un contour à $iso_moi. Un des deux arguments est manquant :" .
				" id_subdivision n°$id_subdivision / id_subdivision_api n°$id_subdivision_api.",
				'subdivisions.' . _LOG_ERREUR);
		} else {
			$url = apigeo_construire_requete($id_subdivision_api);

			// chargement des polygons envoyés par l'API (retour : json)
			$json = recuperer_page($url);

			// extraction des informations pertinentes (retour : json)
			$objet = apigeo_extraire ($id_subdivision_api,$json);

			unset($json); // on libère la mémoire du code json
			
			// enregistrements dans la base de données (retour : id_gis si réussis false dans le cas contraire)
			$id_gis = apigeo_peupler($objet, $id_subdivision);

 			unset($objet); // on libère la mémoire de la partie du code json
 			
			if ($id_gis) {
				// L'utilisateur s'attend à voir l'objet enregistré.
				// La config de GIS, doit permettre cette visualisation.
 				$gis_config = lire_config('gis/gis_objets', array());
 				if (!in_array('spip_subdivisions', $gis_config)) { 
					$gis_config[] = 'spip_subdivisions';
					ecrire_config('gis/gis_objets', $gis_config);
				}
				// L'objet doit être réactualisé pour permettre l'apparition du contour.
				// Il faut donc invalider les caches.
				suivre_invalideur("id='id_subdivision/$id_subdivision'");
				// il faut géré les cas de double correspondance avec un contour.
				if ($d[$iso_moi]) {
					$identifiants = apigeo_correspondances_iso($d[$iso_moi]);
					$id_precedente = $id_subdivision;
					$id_subdivision = $identifiants['id_subdivision'];
					// La subdivision a-t-elle déjà une forme géométrique provenant d'une API ?
					$forme = apigeo_trouver_forme ($id_subdivision, "definition");
					if (!$forme) {
						// liaison entre la forme et la seconde subdivision
						sql_insertq('spip_gis_liens', array(
							'id_gis' => $id_gis,
							'objet' => 'subdivision',
							'id_objet' => $id_subdivision,
							)
						);
						// garder une trace de ce peuplement et de ses conditions pour permettre une mise à jour.
						$champs = array (
							'id_subdivision_api' => $id_subdivision_api,
							'date_peuplement' => date('Y-m-d H:i:s'),
							'id_subdivision' => $id_subdivision,
							'id_gis' => $id_gis,
							'type_relation' => "definition",
							'date' => date('Y-m-d H:i:s'),
							'statut' => "publie"
						);
						$id_peuplement = sql_insertq('spip_subdivisions_peuplements', $champs);
 						spip_log("Fonction importer_spip_gis."
 							. " La forme id_gis n°$id_gis a une double correspondance : $id_precedente et $id_subdivision.",
							'subdivisions.' . _LOG_INFO
						);
					}
				}
			}
		
		}
	}
        
 
}
