<?php
#
# Ces fichiers sont a placer dans le repertoire base/ de votre plugin
#
/**
 * Gestion de l'importation de `spip_subdivisions`
**/

/**
 * Fonction d'import de la table `spip_subdivisions`
 * à utiliser dans le fichier d'administration du plugin
 *
 *     ```
 *     include_spip('base/importer_spip_subdivisions');
 *     $maj['create'][] = array('importer_spip_subdivisions');
 *     ```
 *
**/
function importer_spip_subdivisions() {
	######## VERIFIEZ LE NOM DE LA TABLE D'INSERTION ###########
	$table = 'spip_subdivisions';

	// nom_du_champ_source => nom_du_champ_destination
	// mettre vide la destination ou supprimer la ligne permet de ne pas importer la colonne.

	$correspondances = array(
		'code_3166_2' => 'iso_moi',
		'code_specific' => 'specifique',
		'country' => 'iso_pays',
		'parent' => 'iso_parent',
		'label'	=> 'titre',
		'date' => 'date',
		'statut' => 'statut',
		'maj' => 'date'
	);

	// informations supplémentaires à celles de Nomenclatures (présente en v1.0x du Plugin Regions)

	$trou['FR-GUA'] = array('cog' => '1', 'nuts' => 'FRY1', 'nom_usage' =>'');
	$trou['FR-MTQ'] = array('cog' => '2', 'nuts' => 'FRY2', 'nom_usage' =>'');
	$trou['FR-GUF'] = array('cog' => '3', 'nuts' => 'FRY3', 'nom_usage' =>'');
	$trou['FR-LRE'] = array('cog' => '4', 'nuts' => 'FRY4', 'nom_usage' =>'');
	$trou['FR-MAY'] = array('cog' => '6', 'nuts' => 'FRY5', 'nom_usage' =>'');
	$trou['FR-IDF'] = array('cog' => '11', 'nuts' => 'FR1', 'nom_usage' =>'');
	$trou['FR-CVL'] = array('cog' => '24', 'nuts' => 'FRB', 'nom_usage' =>'');
	$trou['FR-BFC'] = array('cog' => '27', 'nuts' => 'FRC', 'nom_usage' =>'');
	$trou['FR-NOR'] = array('cog' => '28', 'nuts' => 'FRD', 'nom_usage' =>'');
	$trou['FR-HDF'] = array('cog' => '32', 'nuts' => 'FRE', 'nom_usage' =>'');
	$trou['FR-GES'] = array('cog' => '44', 'nuts' => 'FRF', 'nom_usage' =>'');
	$trou['FR-PDL'] = array('cog' => '52', 'nuts' => 'FRG', 'nom_usage' =>'');
	$trou['FR-BRE'] = array('cog' => '53', 'nuts' => 'FRH', 'nom_usage' =>'');
	$trou['FR-NAQ'] = array('cog' => '75', 'nuts' => 'FRI', 'nom_usage' =>'');
	$trou['FR-OCC'] = array('cog' => '76', 'nuts' => 'FRJ', 'nom_usage' =>'');
	$trou['FR-ARA'] = array('cog' => '84', 'nuts' => 'FRK', 'nom_usage' =>'');
	$trou['FR-PAC']	= array('cog' => '93', 'nuts' => 'FRL', 'nom_usage' =>'<multi>[fr]Région Sud[en]Région Sud</multi>');
	$trou['FR-COR']	= array('cog' => '94', 'nuts' => 'FRM', 'nom_usage' =>'');

	// transposer les donnees dans la nouvelle structure
	$inserts = array();
	list($cles, $valeurs) = donnees_spip_subdivisions();
	// on remet les noms des cles dans le tableau de valeur
	// en s'assurant de leur correspondance au passage
	if (is_array($valeurs)) {
		foreach ($valeurs as $v) {
			$i = array();
			foreach ($v as $cle => $valeur) {
				if (isset($correspondances[$cle]) and $correspondances[$cle]) {
					// on ajoute COG, NUTS, nom_usage et statut
					if ($correspondances[$cle] == 'specifique') {
					 	$i['specifique'] = $trou[$i['iso_moi']]['cog'];
					 	$i['nuts'] = $trou[$i['iso_moi']]['nuts'];
					 	$i['nom_usage'] = $trou[$i['iso_moi']]['nom_usage'];
					 	$i['statut'] = 'publie';
					}  else
						$i[ $correspondances[$cle] ] = $valeur;
					
				}
			}
			$inserts[] = $i;
		}
		unset($valeurs);

		// inserer les donnees en base.
		$nb_inseres = 0;
		// ne pas reimporter ceux deja la (en cas de timeout)
		$nb_deja_la = sql_countsel($table);
		$inserts = array_slice($inserts, $nb_deja_la);
		$nb_a_inserer = count($inserts);
		// on decoupe en petit bout (pour reprise sur timeout)
		$inserts = array_chunk($inserts, 100);
		foreach ($inserts as $i) {
			sql_insertq_multi($table, $i);
			$nb_inseres += count($i);
			// serie_alter() relancera la fonction jusqu'a ce que l'on sorte sans timeout.
			if (time() >= _TIME_OUT) {
				// on ecrit un gentil message pour suivre l'avancement.
				echo "<br />Insertion dans $table relanc&eacute;e : ";
				echo "<br />- $nb_deja_la &eacute;taient d&eacute;j&agrave; l&agrave;";
				echo "<br />- $nb_inseres ont &eacute;t&eacute; ins&eacute;r&eacute;s.";
				$a_faire = $nb_a_inserer - $nb_inseres;
				echo "<br />- $a_faire &agrave; faire.";
				return;
			}
		}
	}
}


/**
 * Donnees de la table spip_subdivisions
 *
 * La table spip_iso3166subdivisions
 * ne contient pas encore le code NUTS
 * code_nuts :	Le code d'Eurostat - s'applique actuellement la nomenclature de 2016 :
 				@link: https://eur-lex.europa.eu/legal-content/FR/TXT/HTML/?uri=CELEX:02003R1059-20180118&from=FR
 				ou NORD-PAS-DE-CALAIS-PICARDIE -> Hauts-de-France
 				   ALSACE-CHAMPAGNE-ARDENNE-LORRAINE -> Grand Est
 				   AQUITAINE-LIMOUSIN-POITOU-CHARENTES -> Nouvelle-Aquitaine
 				   LANGUEDOC-ROUSSILLON-MIDI-PYRÉNÉES -> Occitanie
 				   PROVENCE-ALPES-CÔTE D’AZUR -> communique commercialement sous le nom de Région Sud depuis 2018,
 				   bien que l'appellation antérieure demeure la seule officielle
 *				Au 1er janvier 2021 s'appliquera une nouvelle nomenclature.
 *            	@link: https://ec.europa.eu/eurostat/fr/web/nuts/background
 *
**/

function donnees_spip_subdivisions() {

	$table = "iso3166subdivisions";
	$nombre = sql_countsel("spip_".$table);
	if (!$nombre) { // la table n'est pas peuplée, il faut la peupler.
		// utilisation de l'API du Plugin Nomenclatures
		include_spip('isocode_fonctions');
		$resultat = array();
		$resultat = isocode_charger_tables($table);
		if (!$resultat['ok']) { // on a un problème, il faut donc le tracer dans un log
			spip_log(_T('subdivision:log_peupler_iso3166', array(
					'table' => $table,
					'aut' => $GLOBALS['auteur_session']['id_auteur'],
					'err' => print_r($resultat,true)
					)
				), 'subdivisions.' . _LOG_INFO_IMPORTANTE
			);
		}
	}
	$cles = array('code_3166_2', 'code_specific', 'country', 'type', 'parent', 'label', 'maj');
	$valeurs = sql_allfetsel(implode("," , $cles), "spip_" . $table);

	// il faudrait que l'API permette de versionner le paquet de données qui sert au peuplement. A défaut,
	// au jour d'aujourd'hui on sait qu'il manque 2 régions et leurs codes iso que l'on rajoute 
	// à la fin trop brutalement pour que ce plugin ne soit pas en version test.

	// a défaut de versionnage du paquet de donnée on utilise le versionnage de Nomenclatures officielles 0.4.3
	
	if ($GLOBALS['meta']['isocode_base_version'] == 1) {
		$valeurs[] = array( // Martinique
			'code_3166_2' => 'FR-MTQ', //	varchar(6)
			'code_specific' => '2', // char(2)
			'country' => 'FR', //	char(2)
			'type' => 'overseas_region', //	varchar(32)	
			'parent' => '', // varchar(6)
			'label' => '<multi>[fr]Martinique</multi>', //text multi
			'maj' => ''
		);
	
		$valeurs[] = array( // Guyane
			'code_3166_2' => 'FR-GUF', //	varchar(6)
			'code_specific' => '3', // char(2)
			'country' => 'FR', //	char(2)
			'type' => 'overseas_region', //	varchar(32)	
			'parent' => '', // varchar(6)
			'label' => '<multi>[fr]Guyane</multi>', //text multi
			'maj' => ''
		);
	
	// Les régions étant absentes, les départements n'en font pas mention comme parent
	// il faut donc aussi corriger ce point dans le tableau multidimentionnel :

		foreach ($valeurs as $key => $value) {
			if ($value['code_3166_2'] == 'FR-MQ') {
				$valeurs[$key]['parent'] = 'FR-MTQ';
			}
			if ($value['code_3166_2'] == 'FR-GF') {
				$valeurs[$key]['parent'] = 'FR-GUF';
			}
	// on en profite pour retirer des explications entre parenthèses qui n'ont rien à faire dans des titres
			$valeurs[$key]['label'] = trim(preg_replace('#[\(].*?[\)]#', '', $value['label']));
		}
	}


	return array($cles, $valeurs);
}


