<?php
/**
 * Déclarations relatives à la base de données
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Base
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Déclaration des alias de tables et filtres automatiques de champs
 *
 * @pipeline declarer_tables_interfaces
 * @param array $interfaces
 *     Déclarations d'interface pour le compilateur
 * @return array
 *     Déclarations d'interface pour le compilateur
 */
function subdivisions_declarer_tables_interfaces($interfaces) {

	$interfaces['table_des_tables']['subdivisions'] = 'subdivisions';
	$interfaces['table_des_tables']['subdivisions_apis'] = 'subdivisions_apis';
	$interfaces['table_des_tables']['subdivisions_requetes'] = 'subdivisions_requetes';
	
	$interfaces['table_des_traitements']['NOM_USAGE']['sudivisions']= _TRAITEMENT_TYPO;
 	
 	return $interfaces;
}


/**
 * Déclaration des objets éditoriaux
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 *     Description des tables
 * @return array
 *     Description complétée des tables
 */
function subdivisions_declarer_tables_objets_sql($tables) {

	$tables['spip_subdivisions'] = array(
		'texte_retour' => 'icone_retour',
		'texte_objets' => 'subdivision:titre_subdivisions',
		'texte_objet' => 'subdivision:titre_subdivision',
		'texte_modifier' => 'subdivision:icone_modifier_subdivision',
		'texte_creer' => 'subdivision:icone_creer_subdivision',
		'info_aucun_objet'=> 'subdivision:info_aucune_subdivision',
		'info_1_objet' => 'subdivision:info_1_subdivision',
		'info_nb_objets' => 'subdivision:info_nb_subdivisions',
		'texte_logo_objet' => 'subdivision:titre_logo_subdivision',
		'texte_langue_objet' => 'subdivision:titre_langue_subdivision',
		'type' => 'subdivision',
		'principale' => 'oui',
		'field'=> array(
			'id_subdivision'	=> 'bigint(21) NOT NULL',
			'iso_moi' => "varchar(6) DEFAULT '' NOT NULL", // qui suis-je ISO 3166-2
			'iso_parent' => "varchar(6) DEFAULT '' NOT NULL", // sans parent, je suis la 1ère subdivision ISO 3166-2
			'iso_pays' => "char(2) DEFAULT '' NOT NULL",   //  ISO 3166 alpha2
			'nuts'	=> "varchar(6) NOT NULL default ''", // le code européen NUTS
			'specifique' => "varchar(255) DEFAULT '' NOT NULL",  // à votre usage, comme le cog spécifiquement français
			'titre' => 'text NOT NULL', // nom multi
			'nom_usage' => 'text NOT NULL', // nom d'usage multi. Les surnoms, c'est si convivial
			'date' => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL",
			'statut' => "varchar(255) DEFAULT '0' NOT NULL",
			'maj' => "TIMESTAMP NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP"
		),
		'key' => array(
			'PRIMARY KEY' => 'id_subdivision',
			"KEY iso_parent"	=> "iso_parent",
			"KEY iso_pays" => "iso_pays",
			'KEY nuts' => 'nuts',
		),
		'titre' => 'titre AS titre, "" AS lang',
		'date' => "date",
		'champs_editables'  => array('iso_moi', 'iso_parent', 'iso_pays', 'nuts', 'specifique', 'titre', 'nom_usage'),
		'champs_versionnes' => array('iso_moi', 'iso_parent', 'iso_pays', 'nuts', 'specifique', 'titre', 'nom_usage'),
		'rechercher_champs' => array("titre" => 1, "nom_usage" => 2,  "iso_moi" => 6, "nuts" => 5, "specifique" => 8),
		'tables_jointures' => array( 'subdivisions_liens' ),
		'statut'=> array(
			array(
				'champ' => 'statut',
				'publie' => 'publie',
				'previsu' => 'publie,prop,prepa',
				'post_date' => 'date',
				'exception' => array('statut','tout')
			)
		),
		'statut_textes_instituer' => 	array(
			'prepa' => 'texte_statut_en_cours_redaction',
			'prop' => 'texte_statut_propose_evaluation',
			'publie' => 'texte_statut_publie',
			'refuse' => 'texte_statut_refuse',
			'poubelle' => 'texte_statut_poubelle'
		),
		'texte_changer_statut' => 'subdivision:texte_changer_statut'		
	);

$tables['spip_subdivisions_apis'] = array(
		'texte_retour' => 'icone_retour',
		'texte_objets' => 'subdivision_api:titre_subdivisions_apis',
		'texte_objet' => 'subdivision_api:titre_subdivision_api',
		'texte_modifier' => 'subdivision_api:icone_modifier_subdivision_api',
		'texte_creer' => 'subdivision_api:icone_creer_subdivision_api',
		'info_aucun_objet'=> 'subdivision_api:info_aucune_subdivision_api',
		'info_1_objet' => 'subdivision_api:info_1_subdivision_api',
		'info_nb_objets' => 'subdivision_api:info_nb_subdivisions_apis',
		'texte_logo_objet' => 'subdivision_api:titre_logo_subdivision_api',
		'texte_langue_objet' => 'subdivision_api:titre_langue_subdivision_api',
	'type' => 'subdivision_api',
	'principale' => 'oui',
  'field' => array(
	"id_subdivision_api" => "bigint(21) NOT NULL",					// une ressource API
	"iso_moi" => "varchar(6) DEFAULT '' NOT NULL",      // pour la subdivision n°ISO 3166-2
	"titre" => "VARCHAR(255) DEFAULT '' NOT NULL",		// provenant de l'Open Data machin
	"api" => "VARCHAR(255) DEFAULT '' NOT NULL",		// accessible à l'url suivant
	"dataset" => "VARCHAR(255) DEFAULT '' NOT NULL",    // en demandant le jeu de données untel
	"noeud" => "varchar(255) NOT NULL DEFAULT ''", 		// avec le noeud d'informations pertinentes pour notre objet
	"q" => "text DEFAULT '' NOT NULL", 					// (avec pour paramètre) Requête en texte intégral
	"iso_lang" => "VARCHAR(2) DEFAULT '' NOT NULL", 		// (avec pour paramètre) Code langue de 2 lettres
	"rows" => "bigint(21) NOT NULL DEFAULT '10'", 		// (avec pour paramètre) Nombre de lignes de résultat (10 par défaut)
	"start" => "bigint(21) NOT NULL DEFAULT '0'", 		// (avec pour paramètre) Index du premier résultat renvoyé (pagination)
	"sort" => "VARCHAR(255) DEFAULT '' NOT NULL",		// (avec pour paramètre) Critère de tri (champ ou -champ)
	"facet" => "VARCHAR(255) DEFAULT '' NOT NULL",		// (avec pour paramètre) Nom de la facette à activer dans les résultats (si plusieurs séparer par |)
	"refine" => "VARCHAR(255) DEFAULT '' NOT NULL",		// (avec pour paramètre) Refinements à prendre en compte
	"exclude" => "VARCHAR(255) DEFAULT '' NOT NULL",	// (avec pour paramètre) Exclusions à prendre en compte
	"geofilter_distance" => "VARCHAR(255) DEFAULT '' NOT NULL", // (avec pour paramètre) Un point & distance en mètres
	"geofilter_polygon" => "text DEFAULT '' NOT NULL",	// (avec pour paramètre) Un polygone
	"timezone" => "VARCHAR(255) DEFAULT '' NOT NULL",	// (avec pour paramètre) Le fuseau horaire utilisé pour interpréter les dates et heures dans la requête et les données de la réponse.
	"relation" => "varchar(255) NOT NULL DEFAULT 'definition'", // définir la relation à l'objet SPIP (définition ? Element ?)
	"mention" => "varchar(255) NOT NULL DEFAULT''", 	// citer dans la légende de la carte les mentions nécessaires
	"lien" => "varchar(255) NOT NULL DEFAULT''", 	// lien vers les informations associé au jeu de données.
	'date' => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL",
	'statut' => "varchar(255) DEFAULT '0' NOT NULL",
	'maj' => "TIMESTAMP NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP"
	),
  'key' => array(
	"PRIMARY KEY" => "id_subdivision_api",
	"KEY iso_moi" => "iso_moi",
	),
		'titre' => 'titre AS titre, "" AS lang',
		'date' => "date",
		'champs_editables'  => array('iso_moi', 'titre', 'api', 'dataset', 'noeud', 'q', 'iso_lang', 'rows', 'start', 'sort', 'facet', 'refine', 'exclude', 'geofilter_distance', 'geofilter_polygon', 'timezone', 'relation', 'mention', 'lien'),
		'rechercher_champs' => array('iso_moi' => 1, 'mention' => 3, 'dataset' => 6, 'titre' => 8),
		'statut'=> array(
			array(
				'champ' => 'statut',
				'publie' => 'publie',
				'previsu' => 'publie,prop,prepa',
				'post_date' => 'date',
				'exception' => array('statut','tout')
			)
		),
		'statut_textes_instituer' => 	array(
			'prepa' => 'subdivision_api:texte_statut_en_cours_redaction',
			'prop' => 'subdivision_api:texte_statut_propose_evaluation',
			'publie' => 'subdivision_api:texte_statut_publie',
			'refuse' => 'subdivision_api:texte_statut_refuse',
			'poubelle' => 'subdivision_api:texte_statut_poubelle'
		),
		'texte_changer_statut' => 'subdivision_api:texte_changer_statut'		
	);

 
 $tables['spip_subdivisions_peuplements'] = array(
	'type' => 'subdivision_peuplement',
	'principale' => 'oui',
  'field' => array(
	"id_peuplement" => "bigint(21) NOT NULL",		// un joyeux peuplement identifié par un numéro unique
	"id_subdivision_api" => "bigint(21) NOT NULL DEFAULT '0'",			// provenant de l'API machin
	"date_peuplement" => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL",	// réalisé le jour untel
	"id_subdivision" => "bigint(21) NOT NULL DEFAULT '0'",	// qui concerne la subdivision n°id_subdivision
	"id_gis" => "varchar(30) NOT NULL DEFAULT ''",			// et qui a peuplé la table de gis au n°id_gis (ou pas)
	"type_relation" => "varchar(30) NOT NULL DEFAULT 'definir'",		// avec pour role de définir l'objet, d'être un élement de l'objet
	'date' => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL",
	'statut' => "varchar(255) DEFAULT '0' NOT NULL",
	'maj' => "TIMESTAMP NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP"
	),
  'key' => array(
	"PRIMARY KEY" => "id_peuplement",
	"KEY id_subdivision_api" => "id_subdivision_api",
	"KEY id_subdivision" => "id_subdivision",
	"KEY id_gis" => "id_gis",
	"KEY type_relation" => "type_relation"
	),
		'titre' => 'titre AS type_relation, "" AS lang',
		'date' => "date",
		'champs_editables'  => array('id_subdivision_api', 'date_peuplement', 'id_subdivision', 'id_gis', 'type_relation'),
		'rechercher_champs' => array("open_data" => 1),
		'statut'=> array(
			array(
				'champ' => 'statut',
				'publie' => 'publie',
				'previsu' => 'publie,prop,prepa',
				'post_date' => 'date',
				'exception' => array('statut','tout')
			)
		),
		'statut_textes_instituer' => 	array(
			'prepa' => 'texte_statut_en_cours_redaction',
			'prop' => 'texte_statut_propose_evaluation',
			'publie' => 'texte_statut_publie',
			'refuse' => 'texte_statut_refuse',
			'poubelle' => 'texte_statut_poubelle'
		),
		'texte_changer_statut' => 'subdivision_requete:texte_changer_statut'		
	);

 return $tables;

}

/**
 * Déclaration des tables auxiliaires
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 * 		Description des tables
 *			spip_subdivisions_liens. Table de liaisons. Référence des association des subdivisions aux objets.
 *			spip_api_geoloc. API de téléchargement d'objets géolocalisés. 
 *			spip_happy_peuplement. Date de peuplement avec l'API. Id_gis en résultant. Type.
 * @return array
 *     Description complétée des tables
 */

function subdivisions_declarer_tables_auxiliaires($tables) {

 $tables['spip_subdivisions_liens'] = array(
  'field' => array(
	"id_subdivision" => "bigint(21) NOT NULL DEFAULT '0'",
	"id_objet" => "bigint(21) DEFAULT '0' NOT NULL",
	"objet" => "VARCHAR(25) DEFAULT '' NOT NULL",
	"role" => "varchar(30) NOT NULL DEFAULT ''",
	),
  'key' => array(
	"PRIMARY KEY" => "id_subdivision,id_objet,objet,role",
	"KEY id_subdivision" => "id_subdivision",
	"KEY id_objet" => "id_objet",
	"KEY objet" => "objet",
	"KEY role" => "role",
	),
 );


 return $tables;
}
