<?php
/**
 * Gestion du formulaire de d'édition d'une api
 *
 * Ici, une API (Application Programming Interface)
 * est une interface normalisée
 * qui vous permet d'interroger un serveur.
 * Le présent formulaire vous permet de modifier ou de créer
 * des appels aux API en utilisant un ensemble normalisé d'arguments.
 * Afin de permettre l'application d'un principe de subsidiarité,
 * un appel est prévu par subdivision, ce qui permet l'identification
 * de l'API la plus susceptible de régulièrement mettre à jour
 * le contour de ce territoire (souvent l'autorité administrative dudit territoire).
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Formulaires
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');

/**
 * Un simple formulaire de déclaration des saisies
 *
 * Utilisation du plugin Saisies
 *
 * @return array
 *     tableau décrivant les saisies à afficher dans le formulaire d'édition
 **/
 
function formulaires_subdivision_api_saisies($type_edition, $type_icone){
	$saisies = array(
		array( // le fieldset principal
			'saisie' => 'fieldset',
			'options' => array(
				'nom' => 'fieldset_api',
				'label' => $type_edition,
				'icone' => $type_icone,
			),
    		'saisies' => array( // les champs dans le fieldset 
				array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'id_subdivision_api'
					)
				),
				array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'retour',
					)
				),
				array( 
					'saisie' => 'input',
					'options' => array(
						'nom' => 'iso_moi',
						'label' => _T('subdivision:label_iso_moi'),
						'obligatoire' => 'oui',
 					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'titre',
						'conteneur_class' => 'pleine_largeur',
						'label' => _T('subdivision_api:label_titre'),
						'explication' => _T('subdivision_api:label_titre_explication'),
						'obligatoire' => 'oui'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'api',
						'conteneur_class' => 'pleine_largeur',
						'label' => _T('subdivision_api:label_api'),
						'explication' => _T('subdivision_api:label_api_explication'),
						'obligatoire' => 'oui'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'dataset',
						'conteneur_class' => 'pleine_largeur',
						'label' => _T('subdivision_api:label_dataset'),
						'explication' => _T('subdivision_api:label_dataset_explication'),
						'obligatoire' => 'oui'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'noeud',
						'conteneur_class' => 'pleine_largeur',
						'label' => _T('subdivision_api:label_noeud'),
						'explication' => _T('subdivision_api:label_noeud_explication'),
						'obligatoire' => 'oui'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'q',
						'conteneur_class' => 'pleine_largeur',
						'label' => _T('subdivision_api:label_q'),
						'explication' => _T('subdivision_api:label_q_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'iso_lang',
						'label' => _T('subdivision_api:label_lang'),
						'explication' => _T('subdivision_api:label_lang_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'rows',
						'label' => _T('subdivision_api:label_rows'),
						'explication' => _T('subdivision_api:label_rows_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'start',
						'label' => _T('subdivision_api:label_start'),
						'explication' => _T('subdivision_api:label_start_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'sort',
						'label' => _T('subdivision_api:label_sort'),
						'explication' => _T('subdivision_api:label_sort_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'facet',
						'label' => _T('subdivision_api:label_facet'),
						'explication' => _T('subdivision_api:label_facet_explication'),
						'obligatoire' => 'oui'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'refine',
						'label' => _T('subdivision_api:label_refine'),
						'explication' => _T('subdivision_api:label_refine_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'exclude',
						'label' => _T('subdivision_api:label_exclude'),
						'explication' => _T('subdivision_api:label_exclude_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'geofilter_distance',
						'label' => _T('subdivision_api:label_geofilter_distance'),
						'explication' => _T('subdivision_api:label_geofilter_distance_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'geofilter_polygon',
						'label' => _T('subdivision_api:label_geofilter_polygon'),
						'explication' => _T('subdivision_api:label_geofilter_polygon_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'timezone',
						'label' => _T('subdivision_api:label_timezone'),
						'explication' => _T('subdivision_api:label_timezone_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'relation',
						'label' => _T('subdivision_api:label_relation'),
						'explication' => _T('subdivision_api:label_relation_explication'),
						'obligatoire' => 'oui'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'mention',
						'label' => _T('subdivision_api:label_mention'),
						'explication' => _T('subdivision_api:label_mention_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'lien',
						'label' => _T('subdivision_api:label_lien'),
						'explication' => _T('subdivision_api:label_lien_explication')
					)
				),
			)
		)
	);

	return $saisies;
}

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet édité
 *
 * @param int|string $id_subdivision_api
 *     Identifiant de l'api. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return string
 *     Hash du formulaire
 */
function formulaires_editer_subdivision_api_identifier_dist($id_subdivision_api = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	return serialize(array(intval($id_subdivision_api)));
}

/**
 * Chargement du formulaire d'édition de subdivision
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @uses formulaires_editer_objet_charger()
 *
 * @param int|string $id_subdivision_api
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Environnement du formulaire
 */
function formulaires_editer_subdivision_api_charger_dist($id_subdivision_api = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$valeurs = formulaires_editer_objet_charger('subdivision_api', $id_subdivision_api, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	$type_icone = "subdivision-edit-16.png";
	$type_edition = _T('subdivision:icone_modifier_subdivision');

	if ($valeurs['id_subdivision_api'] == 'oui') {
		$type_icone = "subdivision-new-16.png";
		$type_edition = _T('subdivision:icone_creer_subdivision');
	}
		$valeurs['retour'] = $retour;

	// transmettre les valeurs au plugin Saisies pour formulaires

	$valeurs['_mes_saisies'] = formulaires_subdivision_api_saisies($type_edition, $type_icone);
	
	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition de subdivision
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @uses formulaires_editer_objet_verifier()
 *
 * @param int|string $id_subdivision_api
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Tableau des erreurs
 */
function formulaires_editer_subdivision_api_verifier_dist($id_subdivision_api = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	$erreurs = array();

	//$erreurs = formulaires_editer_objet_verifier('subdivision', $id_subdivision_api, array('id_subdivision', 'titre'));

	return $erreurs;
}

/**
 * Traitement du formulaire d'édition de subdivision
 *
 * Traiter les champs postés
 *
 * @uses formulaires_editer_objet_traiter()
 *
 * @param int|string $id_subdivision_api
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Retours des traitements
 */
function formulaires_editer_subdivision_api_traiter_dist($id_subdivision_api = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$retours = formulaires_editer_objet_traiter('subdivision_api', $id_subdivision_api, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	return $retours;
}
